==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/ru-RU/admin/custom_fields/message.php <==
<?php

return array(

    'field' => array(
        'invalid'   => 'Это поле не существует.',
        'already_added'   => 'Поле уже добавлено',
        'none_selected'   => 'No field selected',

        'create' => array(
            'error'   => 'Поле не было создано, попробуйте ещё раз.',
            'success' => 'Поле успешно создано.',
            'assoc_success' => 'Поле успешно добавлено в набор.'
        ),

        'update' => array(
            'error'   => 'Поле не было обновлено, попробуйте ещё раз',
            'success' => 'Поле успешно обновлено.'
        ),

        'delete' => array(
            'confirm'   	=> 'Вы уверены, что хотите удалить это поле?',
            'error'   => 'При удалении поля возникла ошибка. Попробуйте еще раз.',
            'success' => 'Поле было успешно удалено.',
            'in_use'   => 'Поле ещё используется.',
        )

    ),

    'fieldset' => array(

        'does_not_exist' => 'Набор полей не существует',

        'create' => array(
            'error'   => 'Набор полей не был создан, попробуйте ещё раз.',
            'success' => 'Набор полей создан успешно.'
        ),

        'update' => array(
            'error'   => 'Набор полей не был обновлен, попробуйте ещё раз',
            'success' => 'Набор полей успешно обновлён.'
        ),

        'delete' => array(
            'confirm'   	=> 'Вы уверены, что хотите удалить этот набор полей?',
            'error'   => 'При удалении набора полей возникла ошибка. Попробуйте еще раз.',
            'success' => 'Набор полей был успешно удален.',
            'in_use'   => 'Набор полей всё ещё используется.',
        )

    ),

    'fieldset_default_value' => array(

        'error' => 'Ошибка проверки значений полей по умолчанию.',

    ),






);

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/ru-RU/admin/custom_fields/message.php <==
<?php

return array(

    'field' => array(
        'invalid'   => 'Это поле не существует.',
        'already_added'   => 'Поле уже добавлено',
        'none_selected'   => 'Ни одно поле не выбрано',

        'create' => array(
            'error'   => 'Поле не было создано, попробуйте ещё раз.',
            'success' => 'Поле успешно создано.',
            'assoc_success' => 'Поле успешно добавлено в набор.'
        ),

        'update' => array(
            'error'   => 'Поле не было обновлено, попробуйте ещё раз',
            'success' => 'Поле успешно обновлено.'
        ),

        'delete' => array(
            'confirm'   	=> 'Вы уверены, что хотите удалить это поле?',
            'error'   => 'При удалении поля возникла ошибка. Попробуйте еще раз.',
            'success' => 'Поле было успешно удалено.',
            'in_use'   => 'Поле ещё используется.',
        )

    ),

    'fieldset' => array(

        'does_not_exist' => 'Набор полей не существует',

        'create' => array(
            'error'   => 'Набор полей не был создан, попробуйте ещё раз.',
            'success' => 'Набор полей создан успешно.'
        ),

        'update' => array(
            'error'   => 'Набор полей не был обновлен, попробуйте ещё раз',
            'success' => 'Набор полей успешно обновлён.'
        ),

        'delete' => array(
            'confirm'   	=> 'Вы уверены, что хотите удалить этот набор полей?',
            'error'   => 'При удалении набора полей возникла ошибка. Попробуйте еще раз.',
            'success' => 'Набор полей был успешно удален.',
            'in_use'   => 'Набор полей всё ещё используется.',
        )

    ),

    'fieldset_default_value' => array(

        'error' => 'Ошибка проверки значений полей по умолчанию.',

    ),






);
